@@ -219,18 +219,19 @@ static void image_glom_ev_job_finished(EvJob* job, void* user_data)
   
 void ImageGlom::on_ev_job_finished(EvJob* job)
 {
-	if (ev_job_is_failed (job)) {
-		g_warning ("%s", job->error->message);
-		g_object_unref (job);
+  if (ev_job_is_failed (job)) {
+    g_warning ("%s", job->error->message);
+    g_object_unref (job);
 
-		return;
-	}
+    return;
+  }
 
-	ev_document_model_set_document(m_ev_document_model, job->document);
-	ev_document_model_set_page(m_ev_document_model, 1);
-	g_object_unref (job);
-	
-	ev_view_set_loading(m_ev_view, FALSE);
+  ev_document_model_set_document(m_ev_document_model, job->document);
+  ev_document_model_set_page(m_ev_document_model, 1);
+  g_object_unref (job);
+  
+  //TODO: Show that we are no longer loading.
+  //ev_view_set_loading(m_ev_view, FALSE);
 }
 
 const GdaBinary* ImageGlom::get_binary() const
@@ -284,19 +285,19 @@ void ImageGlom::fill_evince_supported_mime_types()
   
   for(GList* l = types_list; l; l = g_list_next(l))
   {
-	  EvTypeInfo *info = (EvTypeInfo *)l->data;
-	  if(!info)
-	    continue;
+    EvTypeInfo *info = (EvTypeInfo *)l->data;
+    if(!info)
+      continue;
 
-	  const char* mime_type = 0;
-	  int i = 0;
-	  while((mime_type = info->mime_types[i++]))
-	  {
-	    if(mime_type)
-	      m_evince_supported_mime_types.push_back(mime_type);
-	    //std::cout << "evince supported mime_type=" << mime_type << std::endl; 
-	  }
-	}  
+    const char* mime_type = 0;
+    int i = 0;
+    while((mime_type = info->mime_types[i++]))
+    {
+      if(mime_type)
+        m_evince_supported_mime_types.push_back(mime_type);
+      //std::cout << "evince supported mime_type=" << mime_type << std::endl; 
+    }
+  }  
 }
 
 void ImageGlom::fill_gdkpixbuf_supported_mime_types()
@@ -382,12 +383,14 @@ void ImageGlom::show_image_data()
   
     m_ev_document_model = ev_document_model_new();
     ev_view_set_model(m_ev_view, m_ev_document_model);
-	  ev_document_model_set_continuous(m_ev_document_model, FALSE); //Show only one page.
-	  ev_view_set_loading(m_ev_view, TRUE);
-	
+    ev_document_model_set_continuous(m_ev_document_model, FALSE); //Show only one page.
+
+    //TODO: Show that we are loading.
+    //ev_view_set_loading(m_ev_view, TRUE);
+
     g_signal_connect (job, "finished",
-		  G_CALLBACK (image_glom_ev_job_finished), this);
-	  ev_job_scheduler_push_job (job, EV_JOB_PRIORITY_NONE);
+      G_CALLBACK (image_glom_ev_job_finished), this);
+    ev_job_scheduler_push_job (job, EV_JOB_PRIORITY_NONE);
   }
   else
   {
@@ -628,12 +631,7 @@ void ImageGlom::open_with(const Glib::RefPtr<Gio::AppInfo>& app_info)
 
   if(app_info)
   {
-    std::vector<std::string> vec_uris;
-    vec_uris.push_back(uri);
-    app_info->launch_uris(vec_uris, 0); //TODO: Get a GdkAppLaunchContext?
-    
-    //TODO Use this instead when we can use glibmm 3.2:
-    //app_info->launch_uri(uri);
+    app_info->launch_uri(uri); //TODO: Get a GdkAppLaunchContext?
   }
   else
   {
