@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
-71 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+71 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "tests/test_selfhosting_utils.h"
@@ -114,6 +114,14 @@ static bool change_privileges(const Glib::ustring& group_name, const Glib::ustri
 
 static bool test(Glom::Document::HostingMode hosting_mode)
 {
+  /* SQLite does not have user/group access levels,
+   * so the SQL queries would fail.
+   */
+  if(hosting_mode == Glom::Document::HOSTING_MODE_SQLITE)
+  {
+    return true;
+  }
+
   //Create and self-host the document:
   Glom::Document document;
     if(!(test_create_and_selfhost_new_database(document, hosting_mode, "test_db")))
@@ -130,7 +138,12 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   table_names.push_back("sometable with space characters");
   table_names.push_back("sometable with a \" doublequote character");
   table_names.push_back("sometable with a ' quote character");
-  table_names.push_back("sometablewithaverylongnameyaddayaddayaddayaddayaddyaddayaddayaddayaddayaddayaddayaddayaddayaddayaddayaddayadda");
+
+  //MySQL has a 64-character limit on SQL identifiers:
+  if(hosting_mode != Glom::Document::HOSTING_MODE_MYSQL_SELF)
+  {
+    table_names.push_back("sometablewithaverylongnameyaddayaddayaddayaddayaddyaddayaddayaddayaddayaddayaddayaddayaddayaddayaddayaddayadda");
+  }
 
   //Add some tables, for the groups to have rights for:
   for(type_vec_strings::const_iterator iter = table_names.begin(); iter != table_names.end(); ++iter)
@@ -143,6 +156,14 @@ static bool test(Glom::Document::HostingMode hosting_mode)
   }
 
 
+  //TODO_MySQL: Implement groups/users code.
+  if(hosting_mode == Glom::Document::HOSTING_MODE_MYSQL_SELF)
+  {
+    test_selfhosting_cleanup(false /* do not delete the file. */);
+    return true;
+  }
+
+
   //Check that only one group exists (the developer group):
   const Glom::Privs::type_vec_strings group_list_original = Glom::Privs::get_database_groups();
   if(group_list_original.empty())
@@ -261,25 +282,10 @@ static bool test(Glom::Document::HostingMode hosting_mode)
 int main()
 {
   Glom::libglom_init();
-  
-  if(!test(Glom::Document::HOSTING_MODE_POSTGRES_SELF))
-  {
-    std::cerr << "Failed with PostgreSQL" << std::endl;
-    test_selfhosting_cleanup();
-    return EXIT_FAILURE;
-  }
-  
-  /* SQLite does not have user/group access levels,
-   * so the SQL queries woudl fail.
-  if(!test(Glom::Document::HOSTING_MODE_SQLITE))
-  {
-    std::cerr << "Failed with SQLite" << std::endl;
-    test_selfhosting_cleanup();
-    return EXIT_FAILURE;
-  }
-  */
+
+  const int result = test_all_hosting_modes(sigc::ptr_fun(&test));
 
   Glom::libglom_deinit();
 
-  return EXIT_SUCCESS;
+  return result;
 }
