@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
-71 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+71 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "tests/test_selfhosting_utils.h"
@@ -38,6 +38,14 @@ bool contains(const T_Container& container, const T_Value& name)
 
 static bool test(Glom::Document::HostingMode hosting_mode)
 {
+  /* SQLite does not have user/group access levels,
+   * so the SQL queries woudl fail.
+   */
+  if(hosting_mode == Glom::Document::HOSTING_MODE_SQLITE)
+  {
+    return true;
+  }
+
   Glib::ustring temp_file_uri;
   const Glib::ustring operator_user = "someoperator";
   const Glib::ustring operator_password = "somepassword";
@@ -60,6 +68,13 @@ static bool test(Glom::Document::HostingMode hosting_mode)
       return false;
     }
 
+    //TODO_MySQL: Implement groups/users code.
+    if(hosting_mode == Glom::Document::HOSTING_MODE_MYSQL_SELF)
+    {
+      test_selfhosting_cleanup(false /* do not delete the file. */);
+      return true;
+    }
+
     //Add an operator user:
     const Glib::ustring operator_group_name = "personnel_department";
     const Glom::DbUtils::type_vec_strings group_list = 
@@ -151,25 +166,10 @@ static bool test(Glom::Document::HostingMode hosting_mode)
 int main()
 {
   Glom::libglom_init();
-  
-  if(!test(Glom::Document::HOSTING_MODE_POSTGRES_SELF))
-  {
-    std::cerr << "Failed with PostgreSQL" << std::endl;
-    test_selfhosting_cleanup();
-    return EXIT_FAILURE;
-  }
-  
-  /* SQLite does not have user/group access levels,
-   * so the SQL queries woudl fail.
-  if(!test(Glom::Document::HOSTING_MODE_SQLITE))
-  {
-    std::cerr << "Failed with SQLite" << std::endl;
-    test_selfhosting_cleanup();
-    return EXIT_FAILURE;
-  }
-  */
+
+  const int result = test_all_hosting_modes(sigc::ptr_fun(&test));
 
   Glom::libglom_deinit();
 
-  return EXIT_SUCCESS;
+  return result;
 }
