@@ -14,8 +14,8 @@
  *
  * You should have received a copy of the GNU General Public
  * License along with this program; if not, write to the
- * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
- * Boston, MA 02111-1307, USA.
+ * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
+ * Boston, MA 02110-1301 USA.
  */
 
 #include "tests/test_selfhosting_utils.h"
@@ -31,6 +31,7 @@
 #include <glibmm/convert.h>
 #include <glibmm/miscutils.h>
 #include <iostream>
+#include "config.h"
 
 static void on_initialize_progress()
 {
@@ -173,6 +174,7 @@ bool test_selfhost(Glom::Document& document, const Glib::ustring& user, const Gl
 bool test_create_and_selfhost_new_empty(Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
 {
   if( (hosting_mode != Glom::Document::HOSTING_MODE_POSTGRES_SELF) &&
+    (hosting_mode != Glom::Document::HOSTING_MODE_MYSQL_SELF) &&
     (hosting_mode != Glom::Document::HOSTING_MODE_SQLITE) )
   {
     std::cerr << G_STRFUNC << ": This test function does not support the specified hosting_mode: " << hosting_mode << std::endl;
@@ -211,7 +213,7 @@ bool test_create_and_selfhost_new_empty(Glom::Document& document, Glom::Document
 
   //We must specify a default username and password:
   Glib::ustring password;
-  const Glib::ustring user = Glom::Privs::get_default_developer_user_name(password);
+  const Glib::ustring user = Glom::Privs::get_default_developer_user_name(password, hosting_mode);
   connection_pool->set_user(user);
   connection_pool->set_password(password);
 
@@ -262,31 +264,68 @@ bool test_create_and_selfhost_new_database(Glom::Document& document, Glom::Docum
   return true;
 }
 
-
-bool test_create_and_selfhost_from_example(const std::string& example_filename, Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
+static bool test_create_and_selfhost_from_example_full_path(const std::string& example_path, Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path = std::string())
 {
   Glib::ustring uri;
-  
-  // Get a URI for the example file:
   try
   {
-    const std::string path =
-       Glib::build_filename(GLOM_DOCDIR_EXAMPLES_NOTINSTALLED,
-         example_filename);
-    uri = Glib::filename_to_uri(path);
+    uri = Glib::filename_to_uri(example_path);
   }
   catch(const Glib::ConvertError& ex)
   {
     std::cerr << G_STRFUNC << ": " << ex.what();
     return false;
   }
-  
+
   return test_create_and_selfhost_from_uri(uri, document, hosting_mode, subdirectory_path);
 }
 
+bool test_create_and_selfhost_from_example(const std::string& example_filename, Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
+{
+  Glib::ustring uri;
+  
+  // Get a URI for the example file:
+  std::string path;
+  try
+  {
+    path =
+       Glib::build_filename(GLOM_DOCDIR_EXAMPLES_NOTINSTALLED,
+         example_filename);
+  }
+  catch(const Glib::ConvertError& ex)
+  {
+    std::cerr << G_STRFUNC << ": " << ex.what();
+    return false;
+  }
+
+  return test_create_and_selfhost_from_example_full_path(path, document, hosting_mode, subdirectory_path);
+}
+
+bool test_create_and_selfhost_from_test_example(const std::string& example_filename, Glom::Document& document, Glom::Document::HostingMode hosting_mode)
+{
+  Glib::ustring uri;
+  
+  // Get a URI for the example file:
+  std::string path;
+  try
+  {
+    path =
+       Glib::build_filename(GLOM_TEST_EXAMPLES_NOTINSTALLED,
+         example_filename);
+  }
+  catch(const Glib::ConvertError& ex)
+  {
+    std::cerr << G_STRFUNC << ": " << ex.what();
+    return false;
+  }
+
+  return test_create_and_selfhost_from_example_full_path(path, document, hosting_mode);
+}
+
 bool test_create_and_selfhost_from_uri(const Glib::ustring& example_file_uri, Glom::Document& document, Glom::Document::HostingMode hosting_mode, const std::string& subdirectory_path)
 {
   if( (hosting_mode != Glom::Document::HOSTING_MODE_POSTGRES_SELF) &&
+    (hosting_mode != Glom::Document::HOSTING_MODE_MYSQL_SELF) &&
     (hosting_mode != Glom::Document::HOSTING_MODE_SQLITE) )
   {
     std::cerr << G_STRFUNC << ": This test function does not support the specified hosting_mode: " << hosting_mode << std::endl;
@@ -302,19 +341,19 @@ bool test_create_and_selfhost_from_uri(const Glib::ustring& example_file_uri, Gl
 
   if(!test)
   {
-    std::cerr << G_STRFUNC << ": Document::load() failed with failure_code=" << failure_code << std::endl;
+    std::cerr << G_STRFUNC << ": Document::load() failed with failure_code=" << failure_code << " for uri=" << example_file_uri << std::endl;
     return false;
   }
 
   if(!document.get_is_example_file() && !document.get_is_backup_file())
   {
-    std::cerr << G_STRFUNC << ": The document is not an example or a backup." << std::endl;
+    std::cerr << G_STRFUNC << ": The document is not an example or a backup. uri=" << example_file_uri << std::endl;
     return false;
   }
 
   if(!test_create_and_selfhost_new_empty(document, hosting_mode, subdirectory_path))
   {
-    std::cerr << G_STRFUNC << ": test_create_and_selfhost_new_empty() failed." << std::endl;
+    std::cerr << G_STRFUNC << ": test_create_and_selfhost_new_empty() failed. uri=" << example_file_uri << std::endl;
     return false;
   }
 
@@ -325,7 +364,7 @@ bool test_create_and_selfhost_from_uri(const Glib::ustring& example_file_uri, Gl
   return recreated;
 }
 
-bool test_model_expected_size(const Glib::RefPtr<Gnome::Gda::DataModel>& data_model, guint columns_count, guint rows_count)
+bool test_model_expected_size(const Glib::RefPtr<const Gnome::Gda::DataModel>& data_model, guint columns_count, guint rows_count)
 {
   if(!data_model)
   {
@@ -353,6 +392,12 @@ bool test_table_exists(const Glib::ustring& table_name, const Glom::Document& do
   //Try to get more rows than intended:
   Glom::Utils::type_vecLayoutFields fieldsToGet;
   Glom::sharedptr<const Glom::Field> field = document.get_field_primary_key(table_name); //To to get some field.
+  if(!field)
+  {
+    std::cerr << G_STRFUNC << "Failure: Could not get primary key for table=" << table_name << std::endl;
+    return false;
+  }
+
   Glom::sharedptr<Glom::LayoutItem_Field> layoutitem = Glom::sharedptr<Glom::LayoutItem_Field>::create();
   layoutitem->set_full_field_details(field);
   fieldsToGet.push_back(layoutitem);
@@ -360,7 +405,7 @@ bool test_table_exists(const Glib::ustring& table_name, const Glom::Document& do
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
     Glom::Utils::build_sql_select_with_where_clause(table_name,
       fieldsToGet);
-  Glib::RefPtr<Gnome::Gda::DataModel> data_model = 
+  const Glib::RefPtr<const Gnome::Gda::DataModel> data_model = 
     Glom::DbUtils::query_execute_select(builder);
   if(!data_model || !(data_model->get_n_columns()))
   {
@@ -371,6 +416,63 @@ bool test_table_exists(const Glib::ustring& table_name, const Glom::Document& do
   return true;
 }
 
+static bool test_example_musiccollection_data_related(const Glom::Document* document, const Gnome::Gda::Value& album_id)
+{
+  if(!document)
+  {
+    std::cerr << G_STRFUNC << ": document is null" << std::endl;
+    return false;
+  }
+
+  Glom::Utils::type_vecLayoutFields fieldsToGet;
+
+  //Normal fields:
+  Glom::sharedptr<const Glom::Field> field_album_id = document->get_field("albums", "album_id");
+  Glom::sharedptr<Glom::LayoutItem_Field> layoutitem = Glom::sharedptr<Glom::LayoutItem_Field>::create();
+  layoutitem->set_full_field_details(field_album_id);
+  fieldsToGet.push_back(layoutitem);
+  Glom::sharedptr<const Glom::Field> field = document->get_field("albums", "name");
+  if(!field)
+  {
+    std::cerr << G_STRFUNC << "Failure: Could not get field." << std::endl;
+    return false;
+  }
+  layoutitem = Glom::sharedptr<Glom::LayoutItem_Field>::create();
+  layoutitem->set_full_field_details(field);
+  fieldsToGet.push_back(layoutitem);
+
+  //Related field:
+  const Glom::sharedptr<Glom::Relationship> relationship = document->get_relationship("albums", "artist");
+  if(!relationship)
+  {
+    std::cerr << "Failure: The relationship could not be found." << std::endl;
+    return false;
+  }
+  layoutitem = Glom::sharedptr<Glom::LayoutItem_Field>::create();
+  layoutitem->set_relationship(relationship);
+  field = document->get_field("artists", "name");
+  if(!field)
+  {
+    std::cerr << G_STRFUNC << "Failure: Could not get field." << std::endl;
+    return false;
+  }
+  layoutitem->set_full_field_details(field);
+  fieldsToGet.push_back(layoutitem);
+
+  const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder =
+    Glom::Utils::build_sql_select_with_key("albums", fieldsToGet, field_album_id, album_id);
+  const Glib::RefPtr<const Gnome::Gda::DataModel> data_model = 
+    Glom::DbUtils::query_execute_select(builder);
+  if(!test_model_expected_size(data_model, 3, 1))
+  {
+    std::cerr << "Failure: Unexpected data model size with query: " << 
+      Glom::Utils::sqlbuilder_get_full_query(builder) << std::endl;
+    return false;
+  }
+  
+  return true;
+}
+
 bool test_example_musiccollection_data(const Glom::Document* document)
 {
   if(!document)
@@ -389,7 +491,13 @@ bool test_example_musiccollection_data(const Glom::Document* document)
   Glom::sharedptr<Glom::LayoutItem_Field> layoutitem = Glom::sharedptr<Glom::LayoutItem_Field>::create();
   layoutitem->set_full_field_details(field);
   fieldsToGet.push_back(layoutitem);
+
   field = document->get_field("albums", "name");
+  if(!field)
+  {
+    std::cerr << G_STRFUNC << "Failure: Could not get field." << std::endl;
+    return false;
+  }
   layoutitem = Glom::sharedptr<Glom::LayoutItem_Field>::create();
   layoutitem->set_full_field_details(field);
   fieldsToGet.push_back(layoutitem);
@@ -397,22 +505,92 @@ bool test_example_musiccollection_data(const Glom::Document* document)
   const Glib::RefPtr<const Gnome::Gda::SqlBuilder> builder = 
     Glom::Utils::build_sql_select_with_where_clause("albums",
       fieldsToGet, where_clause);
-  Glib::RefPtr<Gnome::Gda::DataModel> data_model = 
+  const Glib::RefPtr<const Gnome::Gda::DataModel> data_model = 
     Glom::DbUtils::query_execute_select(builder);
   if(!test_model_expected_size(data_model, 2, 1))
   {
-    std::cerr << "Failure: Unexpected data model size with query: " << 
+    std::cerr << G_STRFUNC << "Failure: Unexpected data model size with query: " << 
       Glom::Utils::sqlbuilder_get_full_query(builder) << std::endl;
     return false;
   }
-  
+
   const int count = Glom::DbUtils::count_rows_returned_by(builder);
   if(count != 1 )
   {
-    std::cerr << "Failure: The COUNT query returned an unexpected value: " << count << std::endl;
+    std::cerr << G_STRFUNC << "Failure: The COUNT query returned an unexpected value: " << count << std::endl;
     return false;
   }
-  
+
+
+  //Get the album's related artist name:
+  const Gnome::Gda::Value album_id = data_model->get_value_at(0, 0);
+  return test_example_musiccollection_data_related(document, album_id);
+}
+
+static bool test_hosting_mode(const SlotTest& slot, Glom::Document::HostingMode hosting_mode, const Glib::ustring name)
+{
+  try
+  {
+    if(!slot(hosting_mode))
+    {
+      std::cerr << "Failed with " << name << std::endl;
+      test_selfhosting_cleanup();
+      return false;
+    }
+  }
+  catch(const std::exception& ex)
+  {
+    std::cerr << "Failed with " << name << " with exception: " << ex.what() << std::endl;
+    test_selfhosting_cleanup();
+    return false;
+  }
+  catch(...)
+  {
+    std::cerr << "Failed with " << name << " with unknown exception: " << std::endl;
+    test_selfhosting_cleanup();
+    return false;
+  }
+
   return true;
 }
 
+int test_all_hosting_modes(const SlotTest& slot)
+{
+  if(!test_hosting_mode(slot, Glom::Document::HOSTING_MODE_SQLITE, "SQLite"))
+    return EXIT_FAILURE;
+
+//Do not test MySQL unless it is enabled in the build,
+//though the functionality is always built in libglom.
+//We usually use GLOM_ENABLE_MYSQL only in the UI code,
+//but let's avoid forcing people to install the MySQL server.
+//Also, Ubuntu's AppArmor will not let use start a MySQL process by default anyway.
+//See https://bugs.launchpad.net/ubuntu/+source/mysql-5.5/+bug/1095370
+#ifdef GLOM_ENABLE_MYSQL
+  if(!test_hosting_mode(slot, Glom::Document::HOSTING_MODE_MYSQL_SELF, "MySQL"))
+    return EXIT_FAILURE;
+#endif //GLOM_ENABLE_MYSQL
+
+  if(!test_hosting_mode(slot, Glom::Document::HOSTING_MODE_POSTGRES_SELF, "PostgreSQL"))
+    return EXIT_FAILURE;
+
+  return EXIT_SUCCESS;
+}
+
+bool test_check_numeric_value_type(Glom::Document::HostingMode hosting_mode, const Gnome::Gda::Value& value)
+{
+  const GType gtype = value.get_value_type();
+  //std::cout << "debug: gtype=" << g_type_name(gtype) << std::endl;
+  if(hosting_mode == Glom::Document::HOSTING_MODE_SQLITE)
+  {
+    if(gtype == G_TYPE_DOUBLE)
+      return true;
+  } else if( (hosting_mode == Glom::Document::HOSTING_MODE_MYSQL_CENTRAL) ||
+    (hosting_mode == Glom::Document::HOSTING_MODE_MYSQL_SELF) )
+  {
+    if(gtype == G_TYPE_DOUBLE)
+      return true;
+  }
+
+  //The normal type for PostgreSQL:
+  return (gtype == GDA_TYPE_NUMERIC);
+}
